@@ -30,10 +30,6 @@ This module requires an IPv6-enabled L<Socket|Socket.pm>. As there is no way to
 #
 #  $cidr = Net::CIDR::Lookup::IPv6->new;
 
-=head1 VERSION HISTORY
-
-See L<Net::CIDR::Lookup::IPv6::Changes>
-
 =head1 METHODS
 
 =cut
@@ -47,7 +43,7 @@ use Socket qw/ inet_ntop inet_pton AF_INET6 /;
 use Bit::Vector;
 use parent 'Net::CIDR::Lookup';
 
-our $VERSION = '0.55';
+use version 0.77; our $VERSION = version->declare('v1.0.0');
 
 =head2 add
 
