@@ -30,10 +30,6 @@ usually far greater than that of explicitly stored key/value pairs.
 
   foreach(keys %h) { ... }			 # Do anything you'd do with a regular hash
 
-=head1 VERSION HISTORY
-
-See L<Net::CIDR::Lookup::Tie::Changes>
-
 =head1 METHODS
 
 =cut
@@ -45,7 +41,7 @@ use warnings;
 use Carp;
 use Net::CIDR::Lookup;
 
-our $VERSION = '0.51';
+use version 0.77; our $VERSION = version->declare('v1.0.0');
 
 sub TIEHASH {   ## no critic (Subroutines::RequireArgUnpacking)
     my $class = shift;
